package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.DataMsg;

/**
 * 配置信息Service接口
 * 
 * @author ruoyi
 * @date 2024-10-09
 */
public interface IDataMsgService 
{
    /**
     * 查询配置信息
     * 
     * @param id 配置信息主键
     * @return 配置信息
     */
    public DataMsg selectDataMsgById(Long id);

    /**
     * 查询配置信息列表
     * 
     * @param dataMsg 配置信息
     * @return 配置信息集合
     */
    public List<DataMsg> selectDataMsgList(DataMsg dataMsg);

    /**
     * 新增配置信息
     * 
     * @param dataMsg 配置信息
     * @return 结果
     */
    public int insertDataMsg(DataMsg dataMsg);

    /**
     * 修改配置信息
     * 
     * @param dataMsg 配置信息
     * @return 结果
     */
    public int updateDataMsg(DataMsg dataMsg);

    /**
     * 批量删除配置信息
     * 
     * @param ids 需要删除的配置信息主键集合
     * @return 结果
     */
    public int deleteDataMsgByIds(String ids);

    /**
     * 删除配置信息信息
     * 
     * @param id 配置信息主键
     * @return 结果
     */
    public int deleteDataMsgById(Long id);

    public Integer dowithsaomaotask(DataMsg dataMsg);

    public Integer insertsaomaodata(DataMsg dataMsg);

}
